enum UnknownSchemaBehavior: string

Defines how queries referencing unknown tables/columns should be handled.

Cases

case Passthrough = 'passthrough'

Pass through to MySQL as-is (current behavior). MySQL will return an error for unknown tables/columns.

case EmptyResult = 'empty'

Return an empty result set. Use for production-like testing where unknown schema should be silently ignored.

case Notice = 'notice'

Output a warning notice and return an empty result set. Use for debugging during development.

case Exception = 'exception'

Throw an UnknownSchemaException. Use for strict testing and fuzz testing.

Test cases 20

Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.

Dedicated tests 4
Other tests reaching this symbol 16

Relations

Constant reads 4
Type declarations 3