enumUnsupportedSqlBehavior
enum UnsupportedSqlBehavior: string
Defines how unsupported SQL statements should be handled.
Cases
case Ignore = 'ignore'Silently ignore unsupported statements (default). Use for production-like testing environments.
case Notice = 'notice'Output a warning notice but continue execution. Use for debugging during development.
case Exception = 'exception'Throw an exception. Use for strict testing and detecting unsupported SQL.
Test cases 30
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 4
Other tests reaching this symbol 26
SqlBehaviorRuleTest::testBehaviorReturnsConfiguredValuecallsSqlBehaviorRuleTest::testComplexRegexPatternscallsSqlBehaviorRuleTest::testIsRegexDetectioncallsSqlBehaviorRuleTest::testMatchesAnswersForTheStatementsTheRuleIsWrittenForcallsSqlBehaviorRuleTest::testPatternReturnsOriginalPatterncallsSqlBehaviorRuleTest::testPrefixDoesNotMatchNonPrefixcallsSqlBehaviorRuleTest::testPrefixMatchesCaseInsensitivecallsSqlBehaviorRuleTest::testPrefixMatchesWithLeadingWhitespacecallsSqlBehaviorRuleTest::testRegexDoesNotMatchNonMatchingcallsSqlBehaviorRuleTest::testRegexMatchescallsZtdConfigTest::testBehaviorRulesReturnsConfiguredRulescallsZtdConfigTest::testDefaultCreatesConfigWithExceptionBehaviorcallsZtdConfigTest::testEmptyBehaviorRulescallsZtdConfigTest::testFirstMatchWinscallsZtdConfigTest::testGetBehaviorForReturnsMatchingRuleBehaviorcallsZtdConfigTest::testGetBehaviorForReturnsNullWhenNoMatchcallsZtdConfigTest::testMixedPrefixAndRegexRulescallsZtdConfigTest::testPrefixMatchingBehaviorcallsZtdConfigTest::testRegexMatchingBehaviorcallsZtdConfigTest::testResolveUnsupportedBehaviorUsesDefaultWhenNoMatchcallsZtdConfigTest::testResolveUnsupportedBehaviorUsesMatchingRulecallsZtdConfigTest::testUnknownSchemaBehaviorReturnsConfiguredValuecallsZtdConfigTest::testUnsupportedBehaviorReturnsConfiguredValuecallsRewriteRefusalTest::testForUnsupportedAnswersAPlanThatDoesNothingWhereTheCallerAllowsThatcallsRewriteRefusalTest::testForUnsupportedRaisesWhereTheCallerAskedToBeToldcallsRewriteRefusalTest::testForUnsupportedSaysSomethingWhereTheCallerAskedToBeNoticedcalls
Relations
Constant reads 3
- class-const ZtdQuery\Config\ZtdConfig::__construct() packages/ztd-query-core/src/Config/ZtdConfig.php:35
- class-const ZtdQuery\RewriteRefusal::forUnsupported() packages/ztd-query-core/src/RewriteRefusal.php:48
- class-const ZtdQuery\RewriteRefusal::forUnsupported() packages/ztd-query-core/src/RewriteRefusal.php:51
Type declarations 8
- type ZtdQuery\Config\SqlBehaviorRule packages/ztd-query-core/src/Config/SqlBehaviorRule.php:25
- type ZtdQuery\Config\SqlBehaviorRule packages/ztd-query-core/src/Config/SqlBehaviorRule.php:31
- type ZtdQuery\Config\SqlBehaviorRule packages/ztd-query-core/src/Config/SqlBehaviorRule.php:55
- type ZtdQuery\Config\ZtdConfig packages/ztd-query-core/src/Config/ZtdConfig.php:15
- type ZtdQuery\Config\ZtdConfig packages/ztd-query-core/src/Config/ZtdConfig.php:35
- type ZtdQuery\Config\ZtdConfig packages/ztd-query-core/src/Config/ZtdConfig.php:59
- type ZtdQuery\Config\ZtdConfig packages/ztd-query-core/src/Config/ZtdConfig.php:88
- type ZtdQuery\Config\ZtdConfig packages/ztd-query-core/src/Config/ZtdConfig.php:104